****************************************************************** .
*This starts identically to syntax "3a.incremental_prediction.sps" .
****************************************************************** .
GET FILE = "All_ESs.sav" .

*Add moderators based on iat_code (within independent samples) . 
MATCH FILES FILE = * / TABLE = "iat_measures.table.sav"
 / BY paper_num sample_num expt_num iat_code .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
*Following moderators will be used in regression analyses .
* i_sd: social desirability concerns .
* e_sd: social desirability concerns .
* control: controllability of criterion responses .
* ib_corr: correspondence between IAT measure and criterion .
* eb_corr: correspondence between explicit measure and criterion .
*e_att_bel_v_self is used as possible BREAK variable and predictor .
IF (e_att_bel_sc <= 2) e_att_bel_v_self = 1 .
IF (e_att_bel_sc = 3) e_att_bel_v_self = 0 .
*i_att_bel_v_self is used as possible BREAK variable and predictor .
IF (i_att_bel_sc <= 2) i_att_bel_v_self = 1 .
IF (i_att_bel_sc = 3) i_att_bel_v_self = 0 .

VARIABLE LABELS i_att_bel_v_self "attitude/stereotype vs. self-concept" .
VALUE LABELS i_att_bel_v_self 0 "IAT measure is self-concept" 
  1  i_att_bel_v_self "IAT measure is att or stereo" .

VARIABLE LABELS e_att_bel_v_self "attitude/stereotype vs. self-concept" .
VALUE LABELS e_att_bel_v_self 0 "expl measure is self-concept"
  1  e_att_bel_v_self "expl measure is att or stereo" .

*FREQUENCIES i_att_bel_v_self e_att_bel_v_self .

AGGREGATE OUTFILE = * / BREAK = paper_num author_names sample_num expt_num 
 / category = FIRST(category)
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) 
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) 
 / num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_bel_v_self e_att_bel_v_self = MEAN 
  (num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_bel_v_self e_att_bel_v_self) .

FREQUENCIES num_ICCs .
SELECT IF (num_ICCs > 0) .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
COMPUTE mean_z_iec = sum_z_X_wt_iec / sum_wt_iec .
EXECUTE .

VARIABLE LABELS 
   mean_wt_icc "icc sample weight"
 / mean_wt_ecc "ecc sample weight"
 / mean_wt_iec "iec sample weight"
 / mean_z_icc "sample average z_icc"
 / mean_z_ecc "sample average z_ecc"
 / mean_z_iec "sample average z_iec" .
DESCRIPTIVES ALL .

IF (category="A") reduced_cat = 1 .
IF (category="B" | category="C") reduced_cat = 2 .
IF (category="D" | category="E" | category="F") reduced_cat = 3 .
IF (category="H" | category="J") reduced_cat = 4 .
IF (category="G" | category="K") reduced_cat = 5 .
IF (category="L") reduced_cat = 6 .

VALUE LABELS reduced_cat
    1 "intergroup behavior - race"  
    2 "intergroup behavior - other"
    3 "consumer preferences" 
    4 "personality traits" 
    5 "clinical & addiction" 
    6 "close relationships" .

FREQUENCIES category reduced_cat .

VARIABLE LABELS i_att_bel_v_self 'Implicit: Att/Belief vs Self-Concept'.
VARIABLE LABELS e_att_bel_v_self 'Explicit: Att/Belief vs Self-Concept'.
VARIABLE LABELS ib_corr 'Correspondence between the IAT and the behavior measure'.
VARIABLE LABELS eb_corr 'Correspondence between the explicit and behavior measure'.
VARIABLE LABELS i_sd 'IAT social sensitivity rating'.
VARIABLE LABELS e_sd 'Explicit social sensitivity rating'.
VARIABLE LABELS control 'controllability rating'. 
VARIABLE LABELS comp 'Complementarity'.

* Basic Tables.
TABLES
  /FORMAT BLANK MISSING('.')
  /OBSERVATION i_sd e_sd control ib_corr eb_corr comp i_att_bel_v_self e_att_bel_v_self mean_z_icc mean_z_ecc mean_z_iec
  /TABLES (i_sd + e_sd + control + ib_corr + eb_corr + comp + i_att_bel_v_self + e_att_bel_v_self + mean_z_icc + mean_z_ecc +
  mean_z_iec)
  BY reduced_cat > (STATISTICS).
