****************************************************************** .
GET FILE = "All_ESs.sav" .
SORT CASES BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .

*Add moderators based on iat_code (within independent samples) . 
MATCH FILES FILE = * / TABLE = "UUIAT3.ICCs.ECCs.moderators.sav"
 / BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
*Following moderators will be used in regression analyses .
* i_sd: social desirability concerns .
* e_sd: social desirability concerns .
* control: controllability of criterion responses .
* ib_corr: correspondence between IAT measure and criterion .
* eb_corr: correspondence between explicit measure and criterion .
*e_att_vs_other is used as possible BREAK variable and predictor .
IF (e_att_bel_sc = 1) e_att_vs_other = 1 .
IF (e_att_bel_sc >=2) e_att_vs_other = 0 .
*i_att_vs_other is used as possible BREAK variable and predictor .
IF (i_att_bel_sc = 1) i_att_vs_other = 1 .
IF (i_att_bel_sc >= 2) i_att_vs_other = 0 .

VARIABLE LABELS i_att_vs_other "attitude vs. other" .
VALUE LABELS i_att_vs_other 0 "IAT is not attitude measure" 
  1  "IAT is attitude measure" .

VARIABLE LABELS e_att_vs_other "attitude vs. other" .
VALUE LABELS e_att_vs_other 0 "expl is not attitude measure" 
  1 "expl is attitude measure" .
FREQUENCIES i_att_bel_sc e_att_bel_sc .
FREQUENCIES i_att_vs_other e_att_vs_other  .

AGGREGATE OUTFILE = * / BREAK = paper_num author_names sample_num expt_num 
 / report_year pub_stat category = FIRST(report_year pub_stat category)
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) 
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) 
 / num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other = MEAN 
  (num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other) .

FREQUENCIES num_ICCs .
SELECT IF (num_ICCs > 0) .

COMPUTE mean_z_icc = sum_z_X_wt_icc / sum_wt_icc .
COMPUTE mean_z_ecc = sum_z_X_wt_ecc / sum_wt_ecc .
COMPUTE mean_z_iec = sum_z_X_wt_iec / sum_wt_iec .
EXECUTE .

VARIABLE LABELS 
   mean_wt_icc "icc sample weight"
 / mean_wt_ecc "ecc sample weight"
 / mean_wt_iec "iec sample weight"
 / mean_z_icc "sample average z_icc"
 / mean_z_ecc "sample average z_ecc"
 / mean_z_iec "sample average z_iec" .
DESCRIPTIVES ALL .


**************************************************************************************** .
* Here starts the weighted regression of ICCs
*  as described by Lipsey & Wilson (2001) on p. 139 .
* Compare weighted regression with the MetaReg.sps macro .
**************************************************************************************** .
Include "MetaReg.sps" .

*Strategy:  Do all regressions both as /model=FE and /model=MM .

*1. Test with all conceptual mediators .
METAREG ES=mean_z_icc /W=mean_wt_icc
  /IVS=mean_z_iec i_att_vs_other i_sd ib_corr control comp /MODEL=FE . 
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=mean_z_iec i_att_vs_other i_sd ib_corr control comp /MODEL=MM . 

*1a. Look at this also without IEC as predictor.
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=i_att_vs_other i_sd ib_corr control comp /MODEL=MM . 

*1b. Repeat with control * i_sd as predictor .
COMPUTE product = control * i_sd .
EXECUTE .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=mean_z_iec i_att_vs_other i_sd ib_corr control comp product /MODEL=MM . 

*1c. Repeat #1 (mixed model), dropping out complementarity .
** This leaves only IEC as significant predictor (knocks out i_sd) .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=mean_z_iec i_att_vs_other i_sd ib_corr control /MODEL=MM . 

*1d. Repeat #1(mixed) again, this time without either complementarity or IEC .
** This doesn't change anything.
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=i_att_vs_other i_sd ib_corr control /MODEL=MM . 

*1e. Repeat #1 (mixed) without political preferences topic (category = F) .
COMPUTE filter$ = (category ne "F") .
FILTER BY filter$ .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=mean_z_iec i_att_vs_other i_sd ib_corr control comp /MODEL=MM . 
FILTER OFF .

*2. Test with each predictor by itself (univariate).
*2a. mean_z_iec .
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=mean_z_iec /MODEL=FE . 
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=mean_z_iec /MODEL=MM . 

*2b. i_att_vs_other .
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=i_att_vs_other  /MODEL=MM . 

*2c. i_sd  .
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=i_sd   /MODEL=MM . 

*2d. ib_corr  .
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=ib_corr   /MODEL=MM . 

*2e. control  .
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=control   /MODEL=MM . 

*2f. comp  .
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=comp   /MODEL=MM . 

*2g. Univariate significant effects found for .
*  mean_z_iec i_sd ib_corr comp .
* Repeat with just these as predictors .
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=mean_z_iec i_sd ib_corr comp /MODEL=FE . 
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=mean_z_iec i_sd ib_corr comp /MODEL=MM . 
* This leaves only mean_z_iec (10**-9) and comp (.0006) as significant predictors .

*2h. Compute correlations among conceptual moderators using SPSS weighted regression.
*  Note this produces weighted correlations among the variables .
REGRESSION / REGWGT = mean_wt_icc / DESCRIPTIVES = CORR
 / DEP = mean_z_icc
 / METHOD = ENTER mean_z_iec i_att_vs_other i_sd control ib_corr comp . 

*2i. Do the same with unweighted regression, just to see how it's different.
REGRESSION / STATISTICS = R CHA COEFF ANOVA ZPP / DESCRIPTIVES = CORR
 / DEP = mean_z_icc
 / METHOD = ENTER mean_z_iec i_att_vs_other i_sd control ib_corr comp . 

DESCRIPTIVS mean_z_iec i_att_vs_other i_sd control ib_corr . 


*************  Analyses of Method Moderators ************** .
* report_year pub_stat num_iats ovr_meth method ms_log wor_pic ipo i_b_pos i_sess iat_type .

FREQUENCIES iat_type method .
*Ignore "method" because of lack of rational way to analyze it (other than as dummy codes).
*Ignore iat_type because almost 90% are one type (dual category).

*Use "ms_log" as ordinal 3-point scale to distinguish improved scoring methods.
*"ovr_meth", "wor_pic", and "i_sess" are usable binary variables .

*"i_b_pos" should be recoded to interchange values of 2 and 3, so "counterbalanced" is intermediate. 
FREQUENCIES i_b_pos ms_log .
RECODE i_b_pos (2=3) (3=2) .
RECODE ms_log (1=0) (2=1) .
FREQUENCIES i_b_pos ms_log .
COMPUTE icc_sample_size = mean_wt_icc + 3 .
EXECUTE .

*3a. Test with all method predictors (include only "i" predictors for ICCs . 
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=num_iccs icc_sample_size num_iats ovr_meth
   ms_log i_b_pos i_sess report_year pub_stat  /MODEL=FE . 
METAREG ES=mean_z_icc /W=mean_wt_icc /IVS=num_iccs icc_sample_size num_iats ovr_meth
   ms_log i_b_pos i_sess report_year pub_stat  /MODEL=MM . 
*No effects significant in MM analysis, 2 effects weakly significant in FE model.


*4. Re-run with predictors one at a time (univariate).
*4a. report_year.
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=report_year  /MODEL=MM . 

*4b. pub_stat .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=pub_stat /MODEL=MM . 

*4c. num_iccs .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=num_iccs /MODEL=MM . 

*4d. icc_sample_size .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=icc_sample_size /MODEL=MM . 

*4e. num_iats .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=num_iats /MODEL=MM . 

*4f. ovr_meth .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=ovr_meth /MODEL=MM . 

*4g. ms_log .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=ms_log /MODEL=MM . 

*4h. i_b_pos .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=i_b_pos /MODEL=MM . 

*4i. i_sess .
METAREG ES=mean_z_icc /W=mean_wt_icc 
  /IVS=i_sess /MODEL=MM . 

*4j. Compute weighted correlations among method moderators using SPSS weighted regression.
*  Note this produces UNweighted correlations among the variables .
REGRESSION / REGWGT = mean_wt_icc  / DESCRIPTIVES = CORR
 / DEP = mean_z_icc
 / METHOD = ENTER report_year pub_stat num_iccs icc_sample_size num_iats ovr_meth 
    ms_log i_b_pos i_sess . 

*Descriptive data for Table 6 of manuscript.
DESCRIPTIVES num_iccs icc_sample_size num_iats ovr_meth
    ms_log i_b_pos i_sess report_year pub_stat . 

