****************************************************************** .
GET FILE = "All_ESs.sav" .
SORT CASES BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .

*Add moderators based on iat_code (within independent samples) . 
MATCH FILES FILE = * / TABLE = "UUIAT3.ICCs.ECCs.moderators.sav"
 / BY paper_num author_names sample_num expt_num crit_code category iat_code self_rep_code .
EXECUTE .

*NOW aggregate to produce a single average weighted effect size for each independent sample .
*Following moderators will be used in regression analyses .
* i_sd: social desirability concerns .
* e_sd: social desirability concerns .
* control: controllability of criterion responses .
* ib_corr: correspondence between IAT measure and criterion .
* eb_corr: correspondence between explicit measure and criterion .
*e_att_vs_other is used as possible BREAK variable and predictor .
IF (e_att_bel_sc = 1) e_att_vs_other = 1 .
IF (e_att_bel_sc >=2) e_att_vs_other = 0 .
*i_att_vs_other is used as possible BREAK variable and predictor .
IF (i_att_bel_sc = 1) i_att_vs_other = 1 .
IF (i_att_bel_sc >= 2) i_att_vs_other = 0 .

VARIABLE LABELS i_att_vs_other "attitude vs. other" .
VALUE LABELS i_att_vs_other 0 "IAT is not attitude measure" 
  1  "IAT is attitude measure" .

VARIABLE LABELS e_att_vs_other "attitude vs. other" .
VALUE LABELS e_att_vs_other 0 "expl is not attitude measure" 
  1 "expl is attitude measure" .
FREQUENCIES i_att_bel_sc e_att_bel_sc .
FREQUENCIES i_att_vs_other e_att_vs_other  .

AGGREGATE OUTFILE = * / BREAK = paper_num author_names sample_num expt_num 
 / report_year pub_stat category = FIRST(report_year pub_stat category)
 / sum_z_X_wt_icc = SUM(z_X_wt_icc) / sum_wt_icc = SUM(wt_icc) / num_ICCs = N(wt_icc)
 / mean_wt_icc = MEAN(wt_icc) 
 / sum_z_X_wt_ecc = SUM(z_X_wt_ecc) / sum_wt_ecc = SUM(wt_ecc) / num_eccs = N(wt_ecc)
 / mean_wt_ecc = MEAN(wt_ecc) 
 / sum_z_X_wt_iec = SUM(z_X_wt_iec) / sum_wt_iec = SUM(wt_iec) / num_iecs = N(wt_iec)
 / mean_wt_iec = MEAN(wt_iec) 
 / num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other = MEAN 
  (num_iats ovr_meth method ms_log wor_pic ipo epo bpo i_b_pos e_b_pos i_sess e_sess i_sd e_sd control ib_corr
  eb_corr comp iat_type i_att_vs_other e_att_vs_other) .

*Recode categories as in other analyses.
*Fold category "H" into "J" .
*Fold category "E" into "D" .
RECODE category ("H" = "J") ("E" = "D") .

VALUE LABELS category
 "A" "race"
 "B" "other intergroup"
 "C" "gender-sex"
 "D" "consumer prefs"
 "F" "politics"
 "G" "drugs or tobacco"
 "J" "personality or self-concept"
 "K" "clinical"
 "L" "relationships" .
EXECUTE .

*Examine means of predictor variables separately by domain.

*Conceptual predictors .
MEANS comp control i_sd e_sd ib_corr eb_corr i_att_vs_other e_att_vs_other BY category .

*Method predictors .
MEANS num_iats ms_log i_b_pos e_b_pos i_sess e_sess i_sess e_sess iat_type BY category .

*Publication predictors .
MEANS pub_stat report_year BY category .


COMPUTE filter$ = (category="D" OR category="F") .
FILTER BY filter$ .
FREQUENCIES i_sd e_sd .
FILTER OFF .

COMPUTE filter$ = (category="A" OR category="B") .
FILTER BY filter$ .
FREQUENCIES i_sd e_sd .
FILTER OFF .

*Separate political topics from the remainder .
COMPUTE filter$ = (category="F") .
MEANS comp control i_sd ib_corr i_att_vs_other BY filter$ .
