*  Siri Carpenter, 9/8/97;
*  Prediss Study 3--Voting Study;
*  This program makes a permanent data set for all 3rd study data.;
*  uses lrt data for IAT analyses;

options linesize=64;

libname alllib 'd:\prediss\study3\sas\std3data';


*************************;

*DATASET:  mini mass survey data;
* note: only half the subjects completed the mini mass survey;

data minimass;
  infile 'd:\prediss\study3\sas\std3data\minimass.txt';
  input subject wldvote malethrm femthrm;

label wldvote='Minimass: would vote (1=male, 7=fem)?'
      malethrm='Minimass: male cand. feeling therm.'
      femthrm='Minimass: female cand. feeling therm.';

*************************;

*DATASET:  political candidates data (voting...);


data cand;
  infile 'd:\prediss\study3\sas\std3data\cand.txt';
  input subject session rnd_seed exp_stat block trial item respac respse
        resprt;

*drop useless variables;
  drop rnd_seed exp_stat block item respac resprt;


*create counterbalancing conditions;

  * CANDIDATE NAME SETS--Lisa Reilly and Gary Nichols or Karen Nichols;
  * and Brian Reilly;
  if session=1 or session=3 or session=5 or session=7 or
     session=9 or session=11 or session=13 or session=15
  then candname='lisagary';
  if session=2 or session=4 or session=6 or session=8 or
     session=10 or session=12 or session=14 or session=16
  then candname='karebria';

  label candname='Candidate name set used';


  * CANDIDATE DESCRIPTION ASSIGNMENT;
    *1=female candidate:2 decades;
    *2=female candidate:18 years;

    if session=1 or session=2 or session=5 or session=6 or
       session=9 or session=10 or session=13 or session=14
    then descassn=1;
    if session=3 or session=4 or session=7 or session=8 or
       session=11 or session=12 or session=15 or session=16
    then descassn=2;

  label descassn='Candidate description assignment';

  * CANDIDATE DESCRIPTION ORDER;
    *1=female/male;
    *2=male/female;

    if session=1 or session=2 or session=3 or session=4 or
       session=9 or session=10 or session=11 or session=12
    then descord=1;
    if session=5 or session=6 or session=7 or session=8 or
       session=13 or session=14 or session=15 or session=16
    then descord=2;

  label descord='Candidate description order';

  * IAT STEREOTYPE ORDER;
    *1=male then female, 2=female then male;

    if session=1 or session=4 or session=5 or session=8 or
       session=9 or session=12 or session=13 or session=16
    then stpord='male1st';
    if session=2 or session=3 or session=6 or session=7 or
       session=10 or session=11 or session=14 or session=15
    then stpord='fem1st';

  label stpord='IAT: Stereotype order';


  * IAT CONFIGURATION ORDER;
    *1=female negative,male positive, then female positive, male negative;
    *2=female positive, male negative, then female negative, male positive;

    if session=1 or session=2 or session=3 or session=4 or
       session=5 or session=6 or session=7 or session=8
    then conf_ord='fneg1st';
    if session=9 or session=10 or session=11 or session=12 or
       session=13 or session=14 or session=15 or session=16
    then conf_ord='fpos1st';

  label conf_ord='IAT: Configuration order';


drop trial; run;

proc sort;
by subject session candname descassn descord stpord conf_ord;  run;

proc transpose
out=temp;
by subject session candname descassn descord stpord conf_ord;  run;


data temp2;
set temp;

  sublim=col15;
  vote=col16;
  femfavor=col17;
  malfavor=col18;
  femsccss=col19;
  malsccss=col20;
  femstrng=col21;
  malstrng=col22;
  femcmpas=col23;
  malcmpas=col24;
  femintel=col25;
  malintel=col26;
  femcoop=col27;
  malcoop=col28;

drop col1-col28;

label sublim='How often did you see sublim. stim?'
      vote='Vote: 1=female, 2=male'
      femfavor='Female cand: favorable?'
      malfavor='Male cand: favorable?'
      femsccss='Female cand: successful?'
      malsccss='Male cand: successful?'
      femstrng='Female cand: strong?'
      malstrng='Male cand: strong?'
      femcmpas='Female cand: compassionate?'
      malcmpas='Male cand: compassionate?'
      femintel='Female cand: intelligent?'
      malintel='Male cand: intelligent?'
      femcoop='Female cand: cooperative?'
      malcoop='Male cand: cooperative?';


************************;

*DATASET: IAT for specific male and female political candidates;

data spec;
  infile 'd:\prediss\study3\sas\std3data\spec.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;


*drop useless variables;
drop rnd_seed exp_stat;


*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=4 or block=8 or block=9
  or block=10 or block=11 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);


*sort spec dataset;
proc sort data=spec;
  by subject;  run;


*eliminate outliers;

  proc summary nway data=spec;
    class subject;
    var lrt;
    output out=temp1  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3stds;
    merge temp1 spec;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;


*create 'CONFIG' conditions;
*1=spfngmps, 2=spfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5 or block=6 or
  block=7) then spconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12 or block=13
  or block=14) then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5 or block=6
  or block=7) then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12 or block=13
  or block=14) then spconfig=1;

* create spstpcon (specific stereotype configuration) conditions;
*1=fngmps_ml, 2=fngmps_fm, 3=fngmps_gn, 4=fpsmng_ml, 5=fpsmng_fm, 6=fpsmng_gn;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=6) then spstpcon=1;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=7) then spstpcon=2;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5) then spstpcon=3;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=13) then spstpcon=4;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=14) then spstpcon=5;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12) then spstpcon=6;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=6) then spstpcon=4;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=7) then spstpcon=5;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5) then spstpcon=6;


 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=13) then spstpcon=1;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=14) then spstpcon=2;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12) then spstpcon=3;


*specify stimulus types by STEROETYPICALITY;
*  if stimtype=5 or stimtype=7 then stp=male;
*  if stimtype=6 or stimtype=8 then stp=female;
*  if stimtype=9 or stimtype=10 then stp=gendneut;

*specify stimulus types by VALENCE;
*  if stimtype=5 or stimtype=6 or stimtype=9 then valence=neg;
*  if stimtype=7 or stimtype=8 or stimtype=10 then valence=pos;

*create 4 STIMULUS CONDITIONS;
* 1=fsppos  2=mspneg  3=fspneg  4=msppos;

if spconfig=2 and (stimtype=2 or stimtype=7 or stimtype=8
                   or stimtype=10) then stimcond=1;

if spconfig=2 and (stimtype=4 or stimtype=5 or stimtype=6
                   or stimtype=9) then stimcond=2;

if spconfig=1 and (stimtype=2 or stimtype=5 or stimtype=6
                   or stimtype=9) then stimcond=3;

if spconfig=1 and (stimtype=4 or stimtype=7 or stimtype=8
                   or stimtype=10) then stimcond=4;


*BREAK DOWN stimulus conditions BY WORD STEREOTYPICALITY;
*examples: FSPPOSML=female leader (specific) positive valence, male stp;
*FSPPOSFM=female leader (specific) positive valence, female stp;
*FSPPOSGN=female leader (specific) positive valence, gender neutral;
*etc.;
* 1=fspposml  2=fspposfm  3=fspposgn;
* 4=mspnegml  5=mspnegfm  6=mspneggn;
* 7=fspnegml  8=fspnegfm  9=fspneggn;
* 10=mspposml  11=mspposfm  12=mspposgn;


if stimcond=1 and (block=6 or block=13) then word=1;
if stimcond=1 and (block=7 or block=14) then word=2;
if stimcond=1 and (block=5 or block=12) then word=3;

if stimcond=2 and (block=6 or block=13) then word=4;
if stimcond=2 and (block=7 or block=14) then word=5;
if stimcond=2 and (block=5 or block=12) then word=6;

if stimcond=3 and (block=6 or block=13) then word=7;
if stimcond=3 and (block=7 or block=14) then word=8;
if stimcond=3 and (block=5 or block=12) then word=9;

if stimcond=4 and (block=6 or block=13) then word=10;
if stimcond=4 and (block=7 or block=14) then word=11;
if stimcond=4 and (block=5 or block=12) then word=12;


*transpose data set for config conditions;
  data cf; set cut3stds;
  proc sort;  by subject spconfig;
  run;
  proc means noprint; by subject spconfig; var lrt;
  output out=meansx mean=lrt;
  run;
  proc transpose data=meansx prefix=lrt
  name=name out=lrtmeanx; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config;
  set lrtmeanx;
  where name = 'LRT';

*rename output variables for 'spconfig' (using lrt data);
spfngmps=LRT1;  spfpsmng=LRT2;
drop LRT1-LRT2;

label spfngmps='SPEC Fcand neg, Mcand pos'
      spfpsmng='SPEC Fcand pos, MCand neg';

run;


*transpose data set for spstpcon conditions;
  data cfstp; set cut3stds;
  proc sort;  by subject spstpcon;
  run;
  proc means noprint; by subject spstpcon; var lrt;
  output out=meansy mean=lrt;
  run;
  proc transpose data=meansy prefix=lrt
  name=name out=lrtmeany; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data stpcon;
  set lrtmeany;
  where name = 'LRT';

*rename output variables for 'spstpcon' (using lrt data);
spfnmpml=LRT1; spfnmpfm=LRT2; spfnmpgn=LRT3;
spfpmnml=LRT4; spfpmnfm=LRT5; spfpmngn=LRT6;
drop LRT1-LRT6;


label spfnmpml='SPEC Fcand neg, Mcand pos, male stp'
      spfnmpfm='SPEC Fcand neg, Mcand pos, female stp'
      spfnmpgn='SPEC Fcand neg, Mcand pos, gend neutral'
      spfpmnml='SPEC Fcand pos, Mcand neg, male stp'
      spfpmnfm='SPEC Fcand pos, Mcand neg, female stp'
      spfpmngn='SPEC Fcand pos, Mcand neg, gend neutral';

run;

*transpose data set for stimcond conditions;
  data sc; set cut3stds;
  proc sort; by subject stimcond;
  run;
  proc means noprint; by subject stimcond; var lrt;
  output out=means mean=lrt;
  run;
  proc transpose data=means prefix=lrt
  name=name out=lrtmeans; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data stimcond;
  set lrtmeans;
  where name = 'LRT';

*rename output variables for 'stimcond' (using lrt data);
fsppos=LRT1;  mspneg=LRT2;  fspneg=LRT3;  msppos=LRT4;
drop LRT1-LRT4;

label fsppos='Fem cand (specific), positive'
      mspneg='Male cand (specific), negative'
      fspneg='Fem cand (specific), negative'
      msppos='Male cand (specific), positive';

run;

*transpose data set for word conditions;
  data w; set cut3stds;
  proc sort; by subject word;
  run;
  proc means noprint; by subject word; var lrt;
  output out=means2 mean=lrt;
  run;
  proc transpose data=means2 prefix=lrt
  name=name out=lrtmean2; by subject;
  run;
  proc sort; by name;
  run;


*drop freq and type variables;
data word;
  set lrtmean2;
  where name = 'LRT';

*rename output variables for 'word' (using lrt data);
fspposml=LRT1;  fspposfm=LRT2;  fspposgn=LRT3;  mspnegml=LRT4;
mspnegfm=LRT5;  mspneggn=LRT6;  fspnegml=LRT7;  fspnegfm=LRT8;
fspneggn=LRT9;  mspposml=LRT10; mspposfm=LRT11; mspposgn=LRT12;
drop LRT1-LRT12;

label fspposml='Fem cand (specific), positive, malstp'
      fspposfm='Fem cand (specific), positive, femstp'
      fspposgn='Fem cand (specific), positive, neutral'
      mspnegml='Male cand (specific), negative, malstp'
      mspnegfm='Male cand (specific), negative, femstp'
      mspneggn='Male cand (specific), negative, neutral'
      fspnegml='Fem cand (specific), negative, malstp'
      fspnegfm='Fem cand (specific), negative, femstp'
      fspneggn='Fem cand (specific), negative, neutral'
      mspposml='Male cand (specific), positive, malstp'
      mspposfm='Male cand (specific), positive, femstp'
      mspposgn='Male cand (specific), positive, neutral';

run;

*************************;


* DATASET: IAT for general male and female political candidates;

data lead;
  infile 'd:\prediss\study3\sas\std3data\lead.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;


*drop useless variables;
drop rnd_seed exp_stat;


*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=4 or block=8 or block=9
  or block=10 or block=11 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);


*sort spec dataset;
proc sort data=lead;
  by subject;  run;


*eliminate outliers;

  proc summary nway data=lead;
    class subject;
    var lrt;
    output out=temp5  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3_x2;
    merge temp5 lead;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;


*create 'CONFIG' conditions;
*1=gfngmps, 2=gfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5 or block=6 or
  block=7) then gconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12 or block=13
  or block=14) then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5 or block=6
  or block=7) then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12 or block=13
  or block=14) then gconfig=1;


* create gstpcon (general stereotype configuration) conditions;
*1=fngmps_ml, 2=fngmps_fm, 3=fngmps_gn, 4=fpsmng_ml, 5=fpsmng_fm, 6=fpsmng_gn;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=6) then gstpcon=1;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=7) then gstpcon=2;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5) then gstpcon=3;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=13) then gstpcon=4;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=14) then gstpcon=5;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12) then gstpcon=6;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=6) then gstpcon=4;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=7) then gstpcon=5;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5) then gstpcon=6;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=13) then gstpcon=1;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=14) then gstpcon=2;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12) then gstpcon=3;


*specify stimulus types by STEROETYPICALITY;
*  if stimtype=5 or stimtype=7 then stp=male;
*  if stimtype=6 or stimtype=8 then stp=female;
*  if stimtype=9 or stimtype=10 then stp=gendneut;

*specify stimulus types by VALENCE;
*  if stimtype=5 or stimtype=6 or stimtype=9 then valence=neg;
*  if stimtype=7 or stimtype=8 or stimtype=10 then valence=pos;

*create 4 STIMULUS CONDITIONS;
* 1=fsppos  2=mspneg  3=fspneg  4=msppos;

if gconfig=2 and (stimtype=2 or stimtype=7 or stimtype=8
                   or stimtype=10) then stimcond=1;

if gconfig=2 and (stimtype=4 or stimtype=5 or stimtype=6
                   or stimtype=9) then stimcond=2;

if gconfig=1 and (stimtype=2 or stimtype=5 or stimtype=6
                   or stimtype=9) then stimcond=3;

if gconfig=1 and (stimtype=4 or stimtype=7 or stimtype=8
                   or stimtype=10) then stimcond=4;


*BREAK DOWN stimulus conditions BY WORD STEREOTYPICALITY;
*examples: FGPOSML=female leader (general) positive valence, male stp;
*FGPOSFM=female leader (general) positive valence, female stp;
*FGPOSGN=female leader (general) positive valence, gender neutral;
*etc.;
* 1=fgposml  2=fgposfm  3=fgposgn;
* 4=mgnegml  5=mgnegfm  6=mgneggn;
* 7=fgnegml  8=fgnegfm  9=fgneggn;
* 10=mgposml  11=mgposfm  12=mgposgn;

if stimcond=1 and (block=6 or block=13) then word=1;
if stimcond=1 and (block=7 or block=14) then word=2;
if stimcond=1 and (block=5 or block=12) then word=3;

if stimcond=2 and (block=6 or block=13) then word=4;
if stimcond=2 and (block=7 or block=14) then word=5;
if stimcond=2 and (block=5 or block=12) then word=6;

if stimcond=3 and (block=6 or block=13) then word=7;
if stimcond=3 and (block=7 or block=14) then word=8;
if stimcond=3 and (block=5 or block=12) then word=9;

if stimcond=4 and (block=6 or block=13) then word=10;
if stimcond=4 and (block=7 or block=14) then word=11;
if stimcond=4 and (block=5 or block=12) then word=12;


*transpose data set for config conditions;
  data cf2; set cut3_x2;
  proc sort;  by subject gconfig;
  run;
  proc means noprint; by subject gconfig; var lrt;
  output out=meansx2 mean=lrt;
  run;
  proc transpose data=meansx2 prefix=lrt
  name=name out=lrtmeax2; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config2;
  set lrtmeax2;
  where name = 'LRT';

*rename output variables for 'gconfig' (using lrt data);
gfngmps=LRT1;  gfpsmng=LRT2;
drop LRT1-LRT2;

label gfngmps='GEN Fem cand, negative, Male Cand positive'
      gfpsmng='GEN Fem cand, positive, Male Cand negative';

run;

*transpose data set for gstpcon conditions;
  data cfstp; set cut3_x2;
  proc sort;  by subject gstpcon;
  run;
  proc means noprint; by subject gstpcon; var lrt;
  output out=meansy2 mean=lrt;
  run;
  proc transpose data=meansy2 prefix=lrt
  name=name out=lrtmeay2; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data stpcon2;
  set lrtmeay2;
  where name = 'LRT';

*rename output variables for 'gstpcon' (using lrt data);
gfnmpml=LRT1; gfnmpfm=LRT2; gfnmpgn=LRT3;
gfpmnml=LRT4; gfpmnfm=LRT5; gfpmngn=LRT6;
drop LRT1-LRT6;


label gfnmpml='GEN F.LEAD neg, M.LEAD pos, male stp'
      gfnmpfm='GEN F.LEAD neg, M.LEAD pos, female stp'
      gfnmpgn='GEN F.LEAD neg, M.LEAD pos, gend neutral'
      gfpmnml='GEN F.LEAD pos, M.LEAD neg, male stp'
      gfpmnfm='GEN F.LEAD pos, M.LEAD neg, female stp'
      gfpmngn='GEN F.LEAD pos, M.LEAD neg, gend neutral';

run;

*transpose data set for stimcond conditions;
  data sc2; set cut3_x2;
  proc sort; by subject stimcond;
  run;
  proc means noprint; by subject stimcond; var lrt;
  output out=means3 mean=lrt;
  run;
  proc transpose data=means3 prefix=lrt
  name=name out=lrtmean3; by subject;
  run;
  proc sort; by name;
  run;


*drop freq and type variables;
data stimcon2;
  set lrtmean3;
  where name = 'LRT';

*rename output variables for 'stimcond' (using lrt data);
fgpos=LRT1;  mgneg=LRT2;  fgneg=LRT3;  mgpos=LRT4;
drop LRT1-LRT4;

label fgpos='Fem cand (general), positive'
      mgneg='Male cand (general), negative'
      fgneg='Fem cand (general), negative'
      mgpos='Male cand (general), positive';

run;

*transpose data set for word conditions;
  data w2; set cut3_x2;
  proc sort; by subject word;
  run;
  proc means noprint; by subject word; var lrt;
  output out=means4 mean=lrt;
  run;
  proc transpose data=means4 prefix=lrt
  name=name out=lrtmean4; by subject;
  run;
  proc sort; by name;
  run;


*drop freq and type variables;
data word2;
  set lrtmean4;
  where name = 'LRT';

*rename output variables for 'word' (using lrt data);
fgposml=LRT1;  fgposfm=LRT2;  fgposgn=LRT3;  mgnegml=LRT4;
mgnegfm=LRT5;  mgneggn=LRT6;  fgnegml=LRT7;  fgnegfm=LRT8;
fgneggn=LRT9;  mgposml=LRT10; mgposfm=LRT11; mgposgn=LRT12;
drop LRT1-LRT12;

label fgposml='Fem cand (general), positive, malstp'
      fgposfm='Fem cand (general), positive, femstp'
      fgposgn='Fem cand (general), positive, neutral'
      mgnegml='Male cand (general), negative, malstp'
      mgnegfm='Male cand (general), negative, femstp'
      mgneggn='Male cand (general), negative, neutral'
      fgnegml='Fem cand (general), negative, malstp'
      fgnegfm='Fem cand (general), negative, femstp'
      fgneggn='Fem cand (general), negative, neutral'
      mgposml='Male cand (general), positive, malstp'
      mgposfm='Male cand (general), positive, femstp'
      mgposgn='Male cand (general), positive, neutral';

run;

*************************

*DATASET:  explicit data;

data explicit;
  infile 'd:\prediss\study3\sas\std3data\explicit.txt';
  input subject 1-3 mcanplea 5-7 fcanplea 8-10 mcanunpl 11-13 fcanunpl 14-16
        mleaplea 18-20 fleaplea 21-23 mleaunpl 24-26 fleaunpl 27-29
        menplea 31-33 womplea 34-36 menunpl 37-39 womunpl 40-42 changenm 44
        caregive 45 affactn 46 edubias 47 era 48 gendlang 49 gendrole 50
        fmnst 52 equal 53 influenc 55 suspect 56 age 58-59 subgend 60
        ethnic 61 bornus 62 yearsus 63-64 english 65 yearseng 66-67
        educatn 68 occup 69;

  label mcanplea='Male candidate: pleasant'
        fcanplea='Female candidate: pleasant'
        mcanunpl='Male candidate: unpleasant'
        fcanunpl='Female candidate: unpleasant'
        mleaplea='Male leaders: pleasant'
        fleaplea='Female leaders: pleasant'
        mleaunpl='Male leaders: unpleasant'
        fleaunpl='Female leaders: unpleasant'
        menplea='Men: pleasant'
        womplea='Women: pleasant'
        menunpl='Men: unpleasant'
        womunpl='Women: unpleasant'
        changenm='When women marry, should not change name'
        caregive='Woman should be the primary caregiver'
        affactn='Affirmative action for women a necessity'
        edubias='Typical college education...male bias'
        era='Existing laws adequate...no need for ERA'
        gendlang='Gender=specific lang. promotes sexism'
        gendrole='Maintaining gender roles=better relat.'
        fmnst='I am a feminist.'
        equal='Not feminist, but believe in equality'
        influenc='Subliminal information influence?'
        suspect='Think phase 1 about gender or stping?'
        subgend='Subject gender'
        ethnic='Ethnicity'
        bornus='Were you born in the United States?'
        yearsus='How long lived in United States?'
        english='Is English your first language?'
        yearseng='How long spoken English fluenty?';

*reverse score feminism items so higher=more feminist;
  caregive=8-caregive;
  era=8-era;
  gendrole=8-gendrole;

proc sort data=explicit;
  by subject;
  run;

*************************


*MERGE ALL DATASETS AND MAKE PERMANENT SAS DATASET;
data alllib.lrtdata;
  merge minimass temp2 config stpcon stimcond word
                       config2 stpcon2 stimcon2 word2 explicit;
  by subject;

*create implicit rai variables;
raifspec=fspneg-fsppos;
raimspec=mspneg-msppos;

raifgen=fgneg-fgpos;
raimgen=mgneg-mgpos;


*create explicit attitude indices;
expfspec=fcanplea-fcanunpl;
expmspec=mcanplea-mcanunpl;

expfgen=fleaplea-fleaunpl;
expmgen=mleaplea-mleaunpl;

expwom=womplea-womunpl;
expmen=menplea-menunpl;

*create preference variable (for male leaders over female leaders);
  spmlpref=spfpsmng-spfngmps;
  gmlpref=gfpsmng-gfngmps;


label raifspec='RAI--Specific Female Leaders'
      raimspec='RAI--Specific Male Leaders'
      raifgen='RAI--General Female Leaders'
      raimgen='RAI--General Male Leaders'
      expfspec='Explicit RAI--Specific Female Leaders'
      expmspec='Explicit RAI--Specific Male Leaders'
      expfgen='Explicit RAI--General Female Leaders'
      expmgen='Explicit RAI--General Male Leaders'
      expwom='Explicit RAI--Women'
      expmen='Explicit RAI--Men'
      spmlpref='Specific Male Leader Preference'
      gmlpref='General Male Leader Preference';

drop _name_ name educatn occup;

*delete subjects;
  if subject=500 then delete;
  if english=0 and yearseng < 10 then delete;
run;
