*  Siri Carpenter, 1/22/98;
*  Prediss Studies 3 and 4--Voting Studies;
*  This program makes a permanent data set for all 3rd and 4th study data.;
*  uses lrt data for IAT analyses;

options linesize=64;

libname mixlib 's:\prediss\study4\sas\std4data';

*STUDY 3 DATA;

*DATASET:  mini mass survey data;
* note: only half the subjects completed the mini mass survey;

data minimass;
  infile 's:\prediss\study3\sas\std3data\minimass.txt';
  input subject wldvote malethrm femthrm;

label wldvote='Minimass: would vote (1=male, 7=fem)?'
      malethrm='Minimass: male cand. feeling therm.'
      femthrm='Minimass: female cand. feeling therm.';

run;

*************************;
*DATASET:  political candidates data (voting...);

data candx;
  infile 's:\prediss\study3\sas\std3data\cand.txt';
  input subject session rnd_seed exp_stat block trial item respac respse
        resprt;

*drop useless variables;
  drop rnd_seed exp_stat block item respac resprt;

*create counterbalancing conditions;

  * CANDIDATE NAME SETS--Lisa Reilly and Gary Nichols or Karen Nichols;
  * and Brian Reilly;
  if session=1 or session=3 or session=5 or session=7 or
     session=9 or session=11 or session=13 or session=15
  then candname='lisagary';
  if session=2 or session=4 or session=6 or session=8 or
     session=10 or session=12 or session=14 or session=16
  then candname='karebria';

  label candname='Candidate name set used';


  * CANDIDATE DESCRIPTION ASSIGNMENT;
    *1=female candidate:2 decades;
    *2=female candidate:18 years;

    if session=1 or session=2 or session=5 or session=6 or
       session=9 or session=10 or session=13 or session=14
    then descassn=1;
    if session=3 or session=4 or session=7 or session=8 or
       session=11 or session=12 or session=15 or session=16
    then descassn=2;

  label descassn='Candidate description assignment';

  * CANDIDATE DESCRIPTION ORDER;
    *1=female/male;
    *2=male/female;

    if session=1 or session=2 or session=3 or session=4 or
       session=9 or session=10 or session=11 or session=12
    then descord=1;
    if session=5 or session=6 or session=7 or session=8 or
       session=13 or session=14 or session=15 or session=16
    then descord=2;

  label descord='Candidate description order';

  * IAT STEREOTYPE ORDER;
    *1=male then female, 2=female then male;

    if session=1 or session=4 or session=5 or session=8 or
       session=9 or session=12 or session=13 or session=16
    then stpord='male1st';
    if session=2 or session=3 or session=6 or session=7 or
       session=10 or session=11 or session=14 or session=15
    then stpord='fem1st';

  label stpord='IAT: Stereotype order';

  * IAT CONFIGURATION ORDER;
    *1=female negative,male positive, then female positive, male negative;
    *2=female positive, male negative, then female negative, male positive;

    if session=1 or session=2 or session=3 or session=4 or
       session=5 or session=6 or session=7 or session=8
    then conf_ord='fneg1st';
    if session=9 or session=10 or session=11 or session=12 or
       session=13 or session=14 or session=15 or session=16
    then conf_ord='fpos1st';

  label conf_ord='IAT: Configuration order';

drop trial; run;

proc sort;
by subject session candname descassn descord stpord conf_ord;  run;

proc transpose
out=tempx;
by subject session candname descassn descord stpord conf_ord;  run;


data temp2x;
set tempx;

  sublim=col15;
  vote=col16;
  femfavor=col17;
  malfavor=col18;
  femsccss=col19;
  malsccss=col20;
  femstrng=col21;
  malstrng=col22;
  femcmpas=col23;
  malcmpas=col24;
  femintel=col25;
  malintel=col26;
  femcoop=col27;
  malcoop=col28;

drop col1-col28;

label sublim='How often did you see sublim. stim?'
      vote='Vote: 1=female, 2=male'
      femfavor='Female cand: favorable?'
      malfavor='Male cand: favorable?'
      femsccss='Female cand: successful?'
      malsccss='Male cand: successful?'
      femstrng='Female cand: strong?'
      malstrng='Male cand: strong?'
      femcmpas='Female cand: compassionate?'
      malcmpas='Male cand: compassionate?'
      femintel='Female cand: intelligent?'
      malintel='Male cand: intelligent?'
      femcoop='Female cand: cooperative?'
      malcoop='Male cand: cooperative?';

run;

************************;

*DATASET: IAT for specific male and female political candidates;

data specx;
  infile 's:\prediss\study3\sas\std3data\spec.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;


*drop useless variables;
drop rnd_seed exp_stat;


*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=4 or block=8 or block=9
  or block=10 or block=11 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);


*sort spec dataset;
proc sort data=specx;
  by subject;  run;


*eliminate outliers;

  proc summary nway data=specx;
    class subject;
    var lrt;
    output out=temp1x  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3stdx;
    merge temp1x specx;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;


*create 'CONFIG' conditions;
*1=spfngmps, 2=spfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5 or block=6 or
  block=7) then spconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12 or block=13
  or block=14) then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5 or block=6
  or block=7) then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12 or block=13
  or block=14) then spconfig=1;

* create spstpcon (specific stereotype configuration) conditions;
*1=fngmps_ml, 2=fngmps_fm, 3=fngmps_gn, 4=fpsmng_ml, 5=fpsmng_fm, 6=fpsmng_gn;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=6) then spstpcon=1;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=7) then spstpcon=2;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5) then spstpcon=3;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=13) then spstpcon=4;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=14) then spstpcon=5;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12) then spstpcon=6;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=6) then spstpcon=4;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=7) then spstpcon=5;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5) then spstpcon=6;


 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=13) then spstpcon=1;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=14) then spstpcon=2;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12) then spstpcon=3;

*transpose data set for config conditions;
  data cfx; set cut3stdx;
  proc sort;  by subject spconfig;
  run;
  proc means noprint; by subject spconfig; var lrt;
  output out=meansxx mean=lrt;
  run;
  proc transpose data=meansxx prefix=lrt
  name=name out=lrtmeaxx; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data configx;
  set lrtmeaxx;
  where name = 'LRT';

*rename output variables for 'spconfig' (using lrt data);
spfngmps=LRT1;  spfpsmng=LRT2;
drop LRT1-LRT2;

label spfngmps='SPEC Fcand neg, Mcand pos'
      spfpsmng='SPEC Fcand pos, MCand neg';

run;

*************************;
* DATASET: IAT for general male and female political candidates;

data leadx;
  infile 's:\prediss\study3\sas\std3data\lead.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;


*drop useless variables;
drop rnd_seed exp_stat;

*delete subject with more than 20% errors;
if subject=10 then delete;

*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=4 or block=8 or block=9
  or block=10 or block=11 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);


*sort lead dataset;
proc sort data=leadx;
  by subject;  run;

*eliminate outliers;

  proc summary nway data=leadx;
    class subject;
    var lrt;
    output out=temp5x  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3_x2x;
    merge temp5x leadx;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;

*create 'CONFIG' conditions;
*1=gfngmps, 2=gfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5 or block=6 or
  block=7) then gconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12 or block=13
  or block=14) then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5 or block=6
  or block=7) then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12 or block=13
  or block=14) then gconfig=1;


* create gstpcon (general stereotype configuration) conditions;
*1=fngmps_ml, 2=fngmps_fm, 3=fngmps_gn, 4=fpsmng_ml, 5=fpsmng_fm, 6=fpsmng_gn;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=6) then gstpcon=1;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=7) then gstpcon=2;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=5) then gstpcon=3;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=13) then gstpcon=4;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=14) then gstpcon=5;

 if (session=1 or session=2 or session=3 or session=4 or session=5
  or session=6 or session=7 or session=8) and (block=12) then gstpcon=6;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=6) then gstpcon=4;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=7) then gstpcon=5;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=5) then gstpcon=6;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=13) then gstpcon=1;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=14) then gstpcon=2;

 if (session=9 or session=10 or session=11 or session=12 or session=13
  or session=14 or session=15 or session=16) and (block=12) then gstpcon=3;

*transpose data set for config conditions;
  data cf2x; set cut3_x2x;
  proc sort;  by subject gconfig;
  run;
  proc means noprint; by subject gconfig; var lrt;
  output out=meansx2x mean=lrt;
  run;
  proc transpose data=meansx2x prefix=lrt
  name=name out=lrtmea2x; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config2x;
  set lrtmea2x;
  where name = 'LRT';

*rename output variables for 'gconfig' (using lrt data);
gfngmps=LRT1;  gfpsmng=LRT2;
drop LRT1-LRT2;

label gfngmps='GEN Fem cand, negative, Male Cand positive'
      gfpsmng='GEN Fem cand, positive, Male Cand negative';

run;

*************************

*DATASET:  explicit data;

data explictx;
  infile 's:\prediss\study3\sas\std3data\explicit.txt';
  input subject 1-3 mcanplea 5-7 fcanplea 8-10 mcanunpl 11-13 fcanunpl 14-16
        mleaplea 18-20 fleaplea 21-23 mleaunpl 24-26 fleaunpl 27-29
        menplea 31-33 womplea 34-36 menunpl 37-39 womunpl 40-42 changenm 44
        caregive 45 affactn 46 edubias 47 era 48 gendlang 49 gendrole 50
        fmnst 52 equal 53 influenc 55 suspect 56 age 58-59 subgend 60
        ethnic 61 bornus 62 yearsus 63-64 english 65 yearseng 66-67
        educatn 68 occup 69;


  label mcanplea='Male candidate: pleasant'
        fcanplea='Female candidate: pleasant'
        mcanunpl='Male candidate: unpleasant'
        fcanunpl='Female candidate: unpleasant'
        mleaplea='Male leaders: pleasant'
        fleaplea='Female leaders: pleasant'
        mleaunpl='Male leaders: unpleasant'
        fleaunpl='Female leaders: unpleasant'
        menplea='Men: pleasant'
        womplea='Women: pleasant'
        menunpl='Men: unpleasant'
        womunpl='Women: unpleasant'
        changenm='When women marry, should not change name'
        caregive='Woman should be the primary caregiver'
        affactn='Affirmative action for women a necessity'
        edubias='Typical college education...male bias'
        era='Existing laws adequate...no need for ERA'
        gendlang='Gender=specific lang. promotes sexism'
        gendrole='Maintaining gender roles=better relat.'
        fmnst='I am a feminist.'
        equal='Not feminist, but believe in equality'
        influenc='Subliminal information influence?'
        suspect='Think phase 1 about gender or stping?'
        subgend='Subject gender'
        ethnic='Ethnicity'
        bornus='Were you born in the United States?'
        yearsus='How long lived in United States?'
        english='Is English your first language?'
        yearseng='How long spoken English fluenty?';

*reverse score feminism items so higher=more feminist;
  caregive=8-caregive;
  era=8-era;
  gendrole=8-gendrole;

proc sort data=explictx;
  by subject;
  run;


data st3all;  merge minimass temp2x configx config2x explictx;  by subject;

if subject=500 then delete;
if english=0 and yearseng < 10 then delete;

subject=500+subject;

run;


**************************************************************;
**************************************************************;
*STUDY 4 DATA;

*************************;

*DATASET:  political candidates data (voting...);

data cand;
  infile 's:\prediss\study4\sas\std4data\Cand.txt';
  input subject session rnd_seed exp_stat block trial item respac respse
        resprt;

*drop useless variables;
  drop rnd_seed exp_stat block item respac resprt;

*create counterbalancing conditions;

  * CANDIDATE NAME SETS--Lisa Reilly and Gary Nichols or Karen Nichols and Brian Reilly;
  if session=1 or session=3 or session=5 or session=7 or
     session=9 or session=11 or session=13 or session=15 or
     session=17 or session=19 or session=21 or session=23 or
     session=25 or session=27 or session=29 or session=31
  then candname='lisagary';
  if session=2 or session=4 or session=6 or session=8 or
     session=10 or session=12 or session=14 or session=16 or
     session=18 or session=20 or session=22 or session=24 or
     session=26 or session=28 or session=30 or session=32
  then candname='karebria';
  label candname='Candidate name set used';

  * CANDIDATE DESCRIPTION ASSIGNMENT;
    *1=female candidate:2 decades;
    *2=female candidate:18 years;
    if session=1 or session=2 or session=5 or session=6 or
       session=9 or session=10 or session=13 or session=14 or
       session=17 or session=18 or session=21 or session=22 or
       session=25 or session=26 or session=29 or session=30
    then descassn=1;
    if session=3 or session=4 or session=7 or session=8 or
       session=11 or session=12 or session=15 or session=16 or
       session=19 or session=20 or session=23 or session=24 or
       session=27 or session=28 or session=31 or session=32
    then descassn=2;
  label descassn='Candidate description assignment';

  * CANDIDATE DESCRIPTION ORDER;
    *1=female/male;
    *2=male/female;
    if session=1 or session=2 or session=3 or session=4 or
       session=9 or session=10 or session=11 or session=12 or
       session=17 or session=18 or session=19 or session=20 or
       session=25 or session=26 or session=27 or session=28
    then descord=1;
    if session=5 or session=6 or session=7 or session=8 or
       session=13 or session=14 or session=15 or session=16 or
       session=21 or session=22 or session=23 or session=24 or
       session=29 or session=30 or session=31 or session=32
    then descord=2;
  label descord='Candidate description order';

  * CANDIDATE STEREOTYPE;
    *1=female stereotype;
    *2=male stereotype;
    if session=1 or session=2 or session=3 or session=4 or
       session=5 or session=6 or session=7 or session=8 or
       session=9 or session=10 or session=11 or session=12 or
       session=13 or session=14 or session=15 or session=16
    then candstp=1;
    if session=17 or session=18 or session=19 or session=20 or
       session=21 or session=22 or session=23 or session=24 or
       session=25 or session=26 or session=27 or session=28 or
       session=29 or session=30 or session=31 or session=32
    then candstp=2;
  label candstp='Candidate stereotype';

  * IAT CONFIGURATION ORDER;
    *1=female negative,male positive, then female positive, male negative;
    *2=female positive, male negative, then female negative, male positive;
    if session=1 or session=2 or session=3 or session=4 or
       session=5 or session=6 or session=7 or session=8 or
       session=17 or session=18 or session=19 or session=20 or
       session=21 or session=22 or session=23 or session=24
    then conf_ord='fneg1st';
    if session=9 or session=10 or session=11 or session=12 or
       session=13 or session=14 or session=15 or session=16 or
       session=25 or session=26 or session=27 or session=28 or
       session=29 or session=30 or session=31 or session=32
    then conf_ord='fpos1st';
  label conf_ord='IAT: Configuration order';

drop trial; run;

proc sort;
by subject session candname descassn descord candstp conf_ord; run;

proc transpose
out=temp;
by subject session candname descassn descord candstp conf_ord; run;

data temp2;
set temp;

  sublim=col15;
  vote=col16;
  femfavor=col17;
  malfavor=col18;
  femsccss=col19;
  malsccss=col20;
  femstrng=col21;
  malstrng=col22;
  femcmpas=col23;
  malcmpas=col24;
  femintel=col25;
  malintel=col26;
  femcoop=col27;
  malcoop=col28;

drop col1-col28;

label sublim='How often did you see sublim. stim?'
      vote='Vote: 1=female, 2=male'
      femfavor='Female cand: favorable?'
      malfavor='Male cand: favorable?'
      femsccss='Female cand: successful?'
      malsccss='Male cand: successful?'
      femstrng='Female cand: strong?'
      malstrng='Male cand: strong?'
      femcmpas='Female cand: compassionate?'
      malcmpas='Male cand: compassionate?'
      femintel='Female cand: intelligent?'
      malintel='Male cand: intelligent?'
      femcoop='Female cand: cooperative?'
      malcoop='Male cand: cooperative?';

run;

************************;
*DATASET: IAT for specific male and female political candidates;

data spec;
  infile 's:\prediss\study4\sas\std4data\spec.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;

*drop useless variables;
drop rnd_seed exp_stat;

*delete subject with more than 20% errors;
if subject=62 or subject=93 then delete;

*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=5 or block=6 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;

*create log reaction time variable;
lrt=log10(resprt);

*sort spec dataset;
proc sort data=spec;
  by subject;  run;

*eliminate outliers;

  proc summary nway data=spec;
    class subject;
    var lrt;
    output out=temp1  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3stds;
    merge temp1 spec;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;


*create 'CONFIG' conditions;
*1=spfngmps, 2=spfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=4 then spconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=7 then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=4 then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=7 then spconfig=1;


*specify stimulus types by VALENCE;
*  if stimtype=9 then valence=neg;
*  if stimtype=10 then valence=pos;

run;

*transpose data set for config conditions;
  data cf; set cut3stds;
  proc sort;  by subject spconfig;
  run;
  proc means noprint; by subject spconfig; var lrt;
  output out=meansx mean=lrt;
  run;
  proc transpose data=meansx prefix=lrt
  name=name out=lrtmeanx; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config;
  set lrtmeanx;
  where name = 'LRT';

*rename output variables for 'spconfig' (using lrt data);
spfngmps=LRT1;  spfpsmng=LRT2;
drop LRT1-LRT2;

label spfngmps='SPEC Fcand neg, Mcand pos'
      spfpsmng='SPEC Fcand pos, MCand neg';

run;

*************************;
* DATASET: IAT for general male and female political candidates;

data lead;
  infile 's:\prediss\study4\sas\std4data\lead.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;

*drop useless variables;
drop rnd_seed exp_stat;

*delete subjects with more than 20% errors;
if subject=93 or subject=44 or subject=58 then delete;


*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=5 or block=6 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);

*sort spec dataset;
proc sort data=lead;
  by subject;  run;

*eliminate outliers;

  proc summary nway data=lead;
    class subject;
    var lrt;
    output out=temp5  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3_x2;
    merge temp5 lead;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;

*create 'CONFIG' conditions;
*1=gfngmps, 2=gfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=4 then gconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=7 then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=4 then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=7 then gconfig=1;

*specify stimulus types by VALENCE;
*  if stimtype=9 then valence=neg;
*  if stimtype=10 then valence=pos;

run;

*transpose data set for config conditions;
  data cf2; set cut3_x2;
  proc sort;  by subject gconfig;
  run;
  proc means noprint; by subject gconfig; var lrt;
  output out=meansx2 mean=lrt;
  run;
  proc transpose data=meansx2 prefix=lrt
  name=name out=lrtmeax2; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config2;
  set lrtmeax2;
  where name = 'LRT';

*rename output variables for 'gconfig' (using lrt data);
gfngmps=LRT1;  gfpsmng=LRT2;
drop LRT1-LRT2;

label gfngmps='GEN Fem lead neg, Male lead pos'
      gfpsmng='GEN Fem lead pos, Male lead neg';

run;

*************************;
*DATASET: IAT for men/women;

data mw;
  infile 's:\prediss\study4\sas\std4data\mw.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;

*drop useless variables;
drop rnd_seed exp_stat;

*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=5 or block=6 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);

*sort spec dataset;
proc sort data=mw;
  by subject;  run;

*eliminate outliers;

  proc summary nway data=mw;
    class subject;
    var lrt;
    output out=temp8  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3_x8;
    merge temp8 mw;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;

*create 'CONFIG' conditions;
*1=mwfngmps, 2=mwfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=4 then mwconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=7 then mwconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=4 then mwconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=7 then mwconfig=1;

*specify stimulus types by VALENCE;
*  if stimtype=9 then valence=neg;
*  if stimtype=10 then valence=pos;

run;

*transpose data set for config conditions;
  data cf2; set cut3_x8;
  proc sort;  by subject mwconfig;
  run;
  proc means noprint; by subject mwconfig; var lrt;
  output out=meansx8 mean=lrt;
  run;
  proc transpose data=meansx8 prefix=lrt
  name=name out=lrtmeax8; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config8;
  set lrtmeax8;
  where name = 'LRT';

*rename output variables for 'mwconfig' (using lrt data);
mwfngmps=LRT1;  mwfpsmng=LRT2;
drop LRT1-LRT2;

label mwfngmps='Women negative, Men positive'
      mwfpsmng='Women positive, Men negative';

run;

*************************;
*DATASET:  explicit data;

data explicit;
  infile 's:\prediss\study4\sas\std4data\explicit.txt';
  input subject 1-2 ExpSpec 4 ExpGen 5 ExpMale 6
        changenm 8 caregive 9 affactn 10 edubias 11 era 12 gendlang 13 gendrole 14
        fmnst 16 equal 17
        sexism01 19 sexism02 20 sexism03 21 sexism04 22 sexism05 23 sexism06 24
        sexism07 25 sexism08 26 sexism09 27 sexism10 28 sexism11 29 sexism12 30
        sexism13 31 sexism14 32 sexism15 33 sexism16 34 sexism17 35 sexism18 36
        sexism19 37 sexism20 38 sexism21 39 sexism22 40
        influenc 42 suspect 43
        age 45-46 subgend 48 ethnic 49 bornus 51 yearsus 52-53 english 54 yearseng 55-56;

  label changenm='When women marry, should not change name'
        caregive='Woman should be the primary caregiver'
        affactn='Affirmative action for women a necessity'
        edubias='Typical college education...male bias'
        era='Existing laws adequate...no need for ERA'
        gendlang='Gender=specific lang. promotes sexism'
        gendrole='Maintaining gender roles=better relat.'
        fmnst='I am a feminist.'
        equal='Not feminist, but believe in equality'
        influenc='Subliminal information influence?'
        suspect='Think phase 1 about gender or stping?'
        subgend='Subject gender'
        ethnic='Ethnicity'
        bornus='Were you born in the United States?'
        yearsus='How long lived in United States?'
        english='Is English your first language?'
        yearseng='How long spoken English fluenty?';

*reverse score explicit preferences so high=male preference;
  ExpSpec=8-ExpSpec;
  ExpGen=8-ExpGen;
  ExpMale=8-ExpMale;

*reverse score feminism items so higher=more feminist;
  caregive=8-caregive;
  era=8-era;
  gendrole=8-gendrole;

proc sort data=explicit;
  by subject;
  run;

*************************;
*MERGE ALL DATASETS AND MAKE PERMANENT SAS DATASET;

data st4all;  merge temp2 config config2 config8 explicit;  by subject;  run;

proc sort data=st3all;  by spfngmps;  run;
proc sort data=st4all;  by spfngmps;  run;

data mixlib.mixdata;
  merge st3all st4all; by spfngmps;

*include counterbalancing data for subjects with missing data in cand section;

if subject=1 then sessionx=1;    if subject=22 then sessionx=22;
if subject=64 then sessionx=32;  if subject=98 then sessionx=23;

*create counterbalancing conditions;

  * CANDIDATE NAME SETS--Lisa Reilly and Gary Nichols or Karen Nichols and Brian Reilly;
  if sessionx=1 or sessionx=23  then candname='lisagary';
  if sessionx=22 or sessionx=32    then candname='karebria';
  label candname='Candidate name set used';

  * CANDIDATE DESCRIPTION ASSIGNMENT;
    *1=female candidate:2 decades;
    *2=female candidate:18 years;
    if sessionx=1 or sessionx=22  then descassn=1;
    if sessionx=23 or sessionx=32 then descassn=2;
  label descassn='Candidate description assignment';

  * CANDIDATE DESCRIPTION ORDER;
    *1=female/male;
    *2=male/female;
    if sessionx=1 then descord=1;
    if sessionx=22 or sessionx=23 or sessionx=32 then descord=2;
  label descord='Candidate description order';

  * CANDIDATE STEREOTYPE;
    *1=female stereotype;
    *2=male stereotype;
    if sessionx=1 then candstp=1;
    if sessionx=22 or sessionx=23 or sessionx=32 then candstp=2;
  label candstp='Candidate stereotype';

  * IAT CONFIGURATION ORDER;
    *1=female negative,male positive, then female positive, male negative;
    *2=female positive, male negative, then female negative, male positive;
    if sessionx=1 or sessionx=22 or sessionx=23 then conf_ord='fneg1st';
    if sessionx=32 then conf_ord='fpos1st';
  label conf_ord='IAT: Configuration order';

*delete subjects;
  if subject=100 then delete;
  if subject=5 then delete;
  if subject=55 then delete;
  if subject=1000 then delete;
  if english=0 and yearseng < 10 then delete;

*create RAI's (implicit preferences for males over females);
  RAIspec=spfpsmng-spfngmps;
  RAIgen=gfpsmng-gfngmps;
  RAImale=mwfpsmng-mwfngmps;

label RAIspec='Implicit Pref. for Specific Male Leader'
      RAIgen='Implicit Pref. for General Male Leader'
      RAImale='Implicit Pref. for Men over Women'
      ExpSpec='Explicit Pref. for Specific Male Leader'
      ExpGen='Explicit Pref. for General Male Leaders'
      ExpMale='Explicit Pref. for Men over Women';

drop _name_ name;

run;
