*  Siri Carpenter, 1/22/98;
*  Prediss Study 4--Voting Study;
*  This program makes a permanent data set for all 4th study data.;
*  uses lrt data for IAT analyses;

options linesize=64;

libname alllib 'g:\prediss\study4\sas\std4data';

*************************;

*DATASET:  political candidates data (voting...);

data cand;
  infile 'g:\prediss\study4\sas\std4data\Cand.txt';
  input subject session rnd_seed exp_stat block trial item respac respse
        resprt;

*drop useless variables;
  drop rnd_seed exp_stat block item respac resprt;

*create counterbalancing conditions;

  * CANDIDATE NAME SETS--Lisa Reilly and Gary Nichols or Karen Nichols and Brian Reilly;
  if session=1 or session=3 or session=5 or session=7 or
     session=9 or session=11 or session=13 or session=15 or
     session=17 or session=19 or session=21 or session=23 or
     session=25 or session=27 or session=29 or session=31
  then candname='lisagary';
  if session=2 or session=4 or session=6 or session=8 or
     session=10 or session=12 or session=14 or session=16 or
     session=18 or session=20 or session=22 or session=24 or
     session=26 or session=28 or session=30 or session=32
  then candname='karebria';
  label candname='Candidate name set used';

  * CANDIDATE DESCRIPTION ASSIGNMENT;
    *1=female candidate:2 decades;
    *2=female candidate:18 years;
    if session=1 or session=2 or session=5 or session=6 or
       session=9 or session=10 or session=13 or session=14 or
       session=17 or session=18 or session=21 or session=22 or
       session=25 or session=26 or session=29 or session=30
    then descassn=1;
    if session=3 or session=4 or session=7 or session=8 or
       session=11 or session=12 or session=15 or session=16 or
       session=19 or session=20 or session=23 or session=24 or
       session=27 or session=28 or session=31 or session=32
    then descassn=2;
  label descassn='Candidate description assignment';

  * CANDIDATE DESCRIPTION ORDER;
    *1=female/male;
    *2=male/female;
    if session=1 or session=2 or session=3 or session=4 or
       session=9 or session=10 or session=11 or session=12 or
       session=17 or session=18 or session=19 or session=20 or
       session=25 or session=26 or session=27 or session=28
    then descord=1;
    if session=5 or session=6 or session=7 or session=8 or
       session=13 or session=14 or session=15 or session=16 or
       session=21 or session=22 or session=23 or session=24 or
       session=29 or session=30 or session=31 or session=32
    then descord=2;
  label descord='Candidate description order';

  * CANDIDATE STEREOTYPE;
    *1=female stereotype;
    *2=male stereotype;
    if session=1 or session=2 or session=3 or session=4 or
       session=5 or session=6 or session=7 or session=8 or
       session=9 or session=10 or session=11 or session=12 or
       session=13 or session=14 or session=15 or session=16
    then candstp=1;
    if session=17 or session=18 or session=19 or session=20 or
       session=21 or session=22 or session=23 or session=24 or
       session=25 or session=26 or session=27 or session=28 or
       session=29 or session=30 or session=31 or session=32
    then candstp=2;
  label candstp='Candidate stereotype';

  * IAT CONFIGURATION ORDER;
    *1=female negative,male positive, then female positive, male negative;
    *2=female positive, male negative, then female negative, male positive;
    if session=1 or session=2 or session=3 or session=4 or
       session=5 or session=6 or session=7 or session=8 or
       session=17 or session=18 or session=19 or session=20 or
       session=21 or session=22 or session=23 or session=24
    then conf_ord='fneg1st';
    if session=9 or session=10 or session=11 or session=12 or
       session=13 or session=14 or session=15 or session=16 or
       session=25 or session=26 or session=27 or session=28 or
       session=29 or session=30 or session=31 or session=32
    then conf_ord='fpos1st';
  label conf_ord='IAT: Configuration order';

drop trial; run;

proc sort;
by subject session candname descassn descord candstp conf_ord; run;

proc transpose
out=temp;
by subject session candname descassn descord candstp conf_ord; run;

data temp2;
set temp;

  sublim=col15;
  vote=col16;
  femfavor=col17;
  malfavor=col18;
  femsccss=col19;
  malsccss=col20;
  femstrng=col21;
  malstrng=col22;
  femcmpas=col23;
  malcmpas=col24;
  femintel=col25;
  malintel=col26;
  femcoop=col27;
  malcoop=col28;

drop col1-col28;

label sublim='How often did you see sublim. stim?'
      vote='Vote: 1=female, 2=male'
      femfavor='Female cand: favorable?'
      malfavor='Male cand: favorable?'
      femsccss='Female cand: successful?'
      malsccss='Male cand: successful?'
      femstrng='Female cand: strong?'
      malstrng='Male cand: strong?'
      femcmpas='Female cand: compassionate?'
      malcmpas='Male cand: compassionate?'
      femintel='Female cand: intelligent?'
      malintel='Male cand: intelligent?'
      femcoop='Female cand: cooperative?'
      malcoop='Male cand: cooperative?';

run;

************************;
*DATASET: IAT for specific male and female political candidates;

data spec;
  infile 'g:\prediss\study4\sas\std4data\spec.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;

*drop useless variables;
drop rnd_seed exp_stat;

*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=5 or block=6 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;

*create log reaction time variable;
lrt=log10(resprt);

*sort spec dataset;
proc sort data=spec;
  by subject;  run;

*eliminate outliers;

  proc summary nway data=spec;
    class subject;
    var lrt;
    output out=temp1  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3stds;
    merge temp1 spec;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;


*create 'CONFIG' conditions;
*1=spfngmps, 2=spfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=4 then spconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=7 then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=4 then spconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=7 then spconfig=1;


*specify stimulus types by VALENCE;
*  if stimtype=9 then valence=neg;
*  if stimtype=10 then valence=pos;

run;

*transpose data set for config conditions;
  data cf; set cut3stds;
  proc sort;  by subject spconfig;
  run;
  proc means noprint; by subject spconfig; var lrt;
  output out=meansx mean=lrt;
  run;
  proc transpose data=meansx prefix=lrt
  name=name out=lrtmeanx; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config;
  set lrtmeanx;
  where name = 'LRT';

*rename output variables for 'spconfig' (using lrt data);
spfngmps=LRT1;  spfpsmng=LRT2;
drop LRT1-LRT2;

label spfngmps='SPEC Fcand neg, Mcand pos'
      spfpsmng='SPEC Fcand pos, MCand neg';

run;

*************************;
* DATASET: IAT for general male and female political candidates;

data lead;
  infile 'g:\prediss\study4\sas\std4data\lead.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;

*drop useless variables;
drop rnd_seed exp_stat;

*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=5 or block=6 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);

*sort spec dataset;
proc sort data=lead;
  by subject;  run;

*eliminate outliers;

  proc summary nway data=lead;
    class subject;
    var lrt;
    output out=temp5  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3_x2;
    merge temp5 lead;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;

*create 'CONFIG' conditions;
*1=gfngmps, 2=gfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=4 then gconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=7 then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=4 then gconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=7 then gconfig=1;

*specify stimulus types by VALENCE;
*  if stimtype=9 then valence=neg;
*  if stimtype=10 then valence=pos;

run;

*transpose data set for config conditions;
  data cf2; set cut3_x2;
  proc sort;  by subject gconfig;
  run;
  proc means noprint; by subject gconfig; var lrt;
  output out=meansx2 mean=lrt;
  run;
  proc transpose data=meansx2 prefix=lrt
  name=name out=lrtmeax2; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config2;
  set lrtmeax2;
  where name = 'LRT';

*rename output variables for 'gconfig' (using lrt data);
gfngmps=LRT1;  gfpsmng=LRT2;
drop LRT1-LRT2;

label gfngmps='GEN Fem lead neg, Male lead pos'
      gfpsmng='GEN Fem lead pos, Male lead neg';

run;

*************************;
*DATASET: IAT for men/women;

data mw;
  infile 'g:\prediss\study4\sas\std4data\mw.txt';
  input subject session rnd_seed exp_stat block trial respac respse resprt
        stimtype ident;

*drop useless variables;
drop rnd_seed exp_stat;

*eliminate trials with zero rt to enable log transformation;
  if resprt = 0 then delete;

*eliminate practice trials;
  if block=1 or block=2 or block=3 or block=5 or block=6 then delete;

*eliminate incorrect responses;
  if respac=0 then delete;


*create log reaction time variable;
lrt=log10(resprt);

*sort spec dataset;
proc sort data=mw;
  by subject;  run;

*eliminate outliers;

  proc summary nway data=mw;
    class subject;
    var lrt;
    output out=temp8  mean=subjmean
                    n=subjn
                    std=subjstd;

  data cut3_x8;
    merge temp8 mw;
    by subject;

  z=(lrt-subjmean)/subjstd;
      if z > 3 then delete;
      if z < -3 then delete;

*create 'CONFIG' conditions;
*1=mwfngmps, 2=mwfpsmng;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=4 then mwconfig=1;

  if (session=1 or session=2 or session=3 or session=4 or
      session=5 or session=6 or session=7 or session=8 or
      session=17 or session=18 or session=19 or session=20 or
      session=21 or session=22 or session=23 or session=24)
      and block=7 then mwconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=4 then mwconfig=2;

  if (session=9 or session=10 or session=11 or session=12 or
      session=13 or session=14 or session=15 or session=16 or
      session=25 or session=26 or session=27 or session=28 or
      session=29 or session=30 or session=31 or session=32)
      and block=7 then mwconfig=1;

*specify stimulus types by VALENCE;
*  if stimtype=9 then valence=neg;
*  if stimtype=10 then valence=pos;

run;

*transpose data set for config conditions;
  data cf2; set cut3_x8;
  proc sort;  by subject mwconfig;
  run;
  proc means noprint; by subject mwconfig; var lrt;
  output out=meansx8 mean=lrt;
  run;
  proc transpose data=meansx8 prefix=lrt
  name=name out=lrtmeax8; by subject;
  run;
  proc sort; by name;
  run;

*drop freq and type variables;
data config8;
  set lrtmeax8;
  where name = 'LRT';

*rename output variables for 'mwconfig' (using lrt data);
mwfngmps=LRT1;  mwfpsmng=LRT2;
drop LRT1-LRT2;

label mwfngmps='Women negative, Men positive'
      mwfpsmng='Women positive, Men negative';

run;

*************************;
*DATASET:  explicit data;

data explicit;
  infile 'g:\prediss\study4\sas\std4data\explicit.txt';
  input subject 1-2 ExpSpec 4 ExpGen 5 ExpMale 6
        changenm 8 caregive 9 affactn 10 edubias 11 era 12 gendlang 13 gendrole 14
        fmnst 16 equal 17
        sexism01 19 sexism02 20 sexism03 21 sexism04 22 sexism05 23 sexism06 24
        sexism07 25 sexism08 26 sexism09 27 sexism10 28 sexism11 29 sexism12 30
        sexism13 31 sexism14 32 sexism15 33 sexism16 34 sexism17 35 sexism18 36
        sexism19 37 sexism20 38 sexism21 39 sexism22 40
        influenc 42 suspect 43
        age 45-46 subgend 48 ethnic 49 bornus 51 yearsus 52-53 english 54 yearseng 55-56;

*reverse scores and create hostile and benevolent sexism indices;

sexism03=(5-sexism03);
sexism06=(5-sexism06);
sexism07=(5-sexism07);
sexism13=(5-sexism13);
sexism18=(5-sexism18);
sexism21=(5-sexism21);

HosSexsm=mean (of sexism02 sexism04 sexism05 sexism07 sexism10
             sexism11 sexism14 sexism15 sexism16 sexism18 sexism21);

BenSexsm=mean (of sexism01 sexism03 sexism06 sexism08 sexism09
             sexism12 sexism13 sexism17 sexism19 sexism20 sexism22);

BenSexI=mean (of sexism01 sexism06 sexism12);
BenSexP=mean (of sexism03 sexism09 sexism17 sexism20);
BenSexG=mean (of sexism08 sexism19 sexism22);


  label changenm='When women marry, should not change name'
        caregive='Woman should be the primary caregiver'
        affactn='Affirmative action for women a necessity'
        edubias='Typical college education...male bias'
        era='Existing laws adequate...no need for ERA'
        gendlang='Gender=specific lang. promotes sexism'
        gendrole='Maintaining gender roles=better relat.'
        fmnst='I am a feminist.'
        equal='Not feminist, but believe in equality'
        influenc='Subliminal information influence?'
        suspect='Think phase 1 about gender or stping?'
        subgend='Subject gender'
        ethnic='Ethnicity'
        bornus='Were you born in the United States?'
        yearsus='How long lived in United States?'
        english='Is English your first language?'
        yearseng='How long spoken English fluenty?'
        HosSexsm='Hostile Sexism'
        BenSexsm='Benevolent Sexism'
        BenSexI='Ben. Sexism: Heterosexual Intimacy'
        BenSexP='Ben. Sexism: Protective Paternalism'
        BenSexG='Ben. Sexism: Complementary Differ.';


*reverse score explicit preferences so high=male preference;
  ExpSpec=8-ExpSpec;
  ExpGen=8-ExpGen;
  ExpMale=8-ExpMale;

*reverse score feminism items so higher=more feminist;
  caregive=8-caregive;
  era=8-era;
  gendrole=8-gendrole;

proc sort data=explicit;
  by subject;
  run;

*************************;
*MERGE ALL DATASETS AND MAKE PERMANENT SAS DATASET;
data alllib.lrtdata;
  merge temp2 config config2 config8 explicit;
  by subject;

*include counterbalancing data for subjects with missing data in cand section;

if subject=1 then sessionx=1;    if subject=22 then sessionx=22;
if subject=64 then sessionx=32;  if subject=98 then sessionx=23;

*create counterbalancing conditions;

  * CANDIDATE NAME SETS--Lisa Reilly and Gary Nichols or Karen Nichols and Brian Reilly;
  if sessionx=1 or sessionx=23  then candname='lisagary';
  if sessionx=22 or sessionx=32    then candname='karebria';
  label candname='Candidate name set used';

  * CANDIDATE DESCRIPTION ASSIGNMENT;
    *1=female candidate:2 decades;
    *2=female candidate:18 years;
    if sessionx=1 or sessionx=22  then descassn=1;
    if sessionx=23 or sessionx=32 then descassn=2;
  label descassn='Candidate description assignment';

  * CANDIDATE DESCRIPTION ORDER;
    *1=female/male;
    *2=male/female;
    if sessionx=1 then descord=1;
    if sessionx=22 or sessionx=23 or sessionx=32 then descord=2;
  label descord='Candidate description order';

  * CANDIDATE STEREOTYPE;
    *1=female stereotype;
    *2=male stereotype;
    if sessionx=1 then candstp=1;
    if sessionx=22 or sessionx=23 or sessionx=32 then candstp=2;
  label candstp='Candidate stereotype';

  * IAT CONFIGURATION ORDER;
    *1=female negative,male positive, then female positive, male negative;
    *2=female positive, male negative, then female negative, male positive;
    if sessionx=1 or sessionx=22 or sessionx=23 then conf_ord='fneg1st';
    if sessionx=32 then conf_ord='fpos1st';
  label conf_ord='IAT: Configuration order';

*delete subjects;
  if subject ge 100 then delete;
  if subject=5 then delete;
  if subject=55 then delete;
  if english=0 and yearseng < 10 then delete;

*create RAI's (implicit preferences for males over females);
  RAIspec=spfpsmng-spfngmps;
  RAIgen=gfpsmng-gfngmps;
  RAImale=mwfpsmng-mwfngmps;

label RAIspec='Implicit Pref. for Specific Male Leader'
      RAIgen='Implicit Pref. for General Male Leader'
      RAImale='Implicit Pref. for Men over Women'
      ExpSpec='Explicit Pref. for Specific Male Leader'
      ExpGen='Explicit Pref. for General Male Leaders'
      ExpMale='Explicit Pref. for Men over Women';

drop _name_ name;

run;
